Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(266)

Unified Diff: tests/compiler/dart2js_extra/this_redirecting_constructor_test.dart

Issue 11140018: Ensure that ClassElement.lookupConstructor fails when looking up default constructor using Selector… (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fixed redirecting constructor lookup logic. Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/compiler/dart2js_extra/this_redirecting_constructor_test.dart
diff --git a/tests/language/constructor_redirect2_negative_test.dart b/tests/compiler/dart2js_extra/this_redirecting_constructor_test.dart
similarity index 52%
copy from tests/language/constructor_redirect2_negative_test.dart
copy to tests/compiler/dart2js_extra/this_redirecting_constructor_test.dart
index bbb03c60884e79ead1cd57038c2027dc8ce92665..078e131f9894c335beb77d58629eeed5d8bebd0b 100644
--- a/tests/language/constructor_redirect2_negative_test.dart
+++ b/tests/compiler/dart2js_extra/this_redirecting_constructor_test.dart
@@ -1,19 +1,17 @@
-// Copyright (c) 2011, the Dart project authors. Please see the AUTHORS file
-// for details. All rights reserved. Use of this source code is governed by a
-// BSD-style license that can be found in the LICENSE file.
-// Redirection constructors must not be cyclic.
-
-class A {
- var x;
- A(x) : this(0);
-}
-
-class ConstructorRedirect2NegativeTest {
- static testMain() {
- new A(10);
- }
-}
-
-main() {
- ConstructorRedirect2NegativeTest.testMain();
-}
+// Copyright (c) 2011, the Dart project authors. Please see the AUTHORS file
+// for details. All rights reserved. Use of this source code is governed by a
+// BSD-style license that can be found in the LICENSE file.
+
+// Confirm that redirecting named constructors are properly resolved.
+
+class C {
+ var x;
+ C() { x = 1; }
+ C.C() { x = 2; }
+ C.redirecting(): this.C();
+}
+
+main() {
+ var c = new C.redirecting();
+ Expect.equals(c.x, 2);
+}
« lib/compiler/implementation/resolver.dart ('K') | « tests/compiler/dart2js/resolver_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698